@@ -19,8 +19,8 @@ class MultiqcModule(BaseMultiqcModule):
             name="bcl2fastq",
             anchor="bcl2fastq",
             href="https://support.illumina.com/sequencing/sequencing_software/bcl2fastq-conversion-software.html",
-            info="can be used to both demultiplex data and convert BCL files"
-            " to FASTQ file formats for downstream analysis.",
+            info="can be used to both demultiplex data and convert BCL files to FASTQ file formats for downstream analysis.",
+            # Can't find a DOI // doi=
         )
 
         # Gather data from all json files
