@@ -174,6 +174,7 @@ def custom_module_classes():
                     # Guess c_id if no information known
                     if k == "custom_content":
                         c_id = s_name
+                        m_config["id"] = c_id
 
                     # Merge with config from a MultiQC config file if we have it
                     m_config.update(mod_cust_config.get(c_id, {}))
@@ -316,6 +317,7 @@ class MultiqcModule(BaseMultiqcModule):
             href=mod["config"].get("section_href"),
             info=mod_info,
             extra=mod["config"].get("extra"),
+            # No DOI here.. // doi=
         )
 
         # Don't repeat the Custom Content name in the subtext
@@ -349,21 +351,28 @@ class MultiqcModule(BaseMultiqcModule):
         section_description = mod["config"].get("description", "")
 
         pconfig = mod["config"].get("pconfig", {})
+        if pconfig.get("id") is None:
+            pconfig["id"] = f"{c_id}-plot"
         if pconfig.get("title") is None:
             pconfig["title"] = section_name
 
         plot = None
         content = None
 
+        # Save the data if it's not a html string
+        if not isinstance(mod["data"], str):
+            self.write_data_file(mod["data"], "multiqc_{}".format(pconfig["id"]))
+            pconfig["save_data_file"] = False
+
         # Table
         if mod["config"].get("plot_type") == "table":
             pconfig["sortRows"] = pconfig.get("sortRows", False)
             headers = mod["config"].get("headers")
             plot = table.plot(mod["data"], headers, pconfig)
-            self.write_data_file(mod["data"], "multiqc_{}".format(section_name.lower().replace(" ", "_")))
 
         # Bar plot
         elif mod["config"].get("plot_type") == "bargraph":
+            mod["data"] = {k: v for k, v in sorted(mod["data"].items())}
             plot = bargraph.plot(mod["data"], mod["config"].get("categories"), pconfig)
 
         # Line plot
