@@ -25,10 +25,8 @@ class MultiqcModule(BaseMultiqcModule, GroupReadsByUmiMixin):
             anchor="fgbio",
             target="fgbio",
             href="http://fulcrumgenomics.github.io/fgbio/",
-            info=(
-                "  is a command line toolkit for working with genomic and "
-                "particularly next generation sequencing data.."
-            ),
+            info=" is a command line toolkit for working with genomic and particularly next generation sequencing data..",
+            # No publication / DOI // doi=
         )
 
         # Set up class objects to hold parsed data
