@@ -24,6 +24,7 @@ class MultiqcModule(BaseMultiqcModule):
             anchor="mirtrace",
             href="https://github.com/friedlanderlab/mirtrace",
             info="is a quality control software for small RNA sequencing data developed by Friedländer lab (KTH, Sweden).",
+            doi="10.1186/s13059-018-1588-9",
         )
 
         # Find and load miRTrace summary statistics table
@@ -282,30 +283,30 @@ class MultiqcModule(BaseMultiqcModule):
 
         # A library of 24 colors. Should be enough for this plot
         color_lib = [
-            "rgb(166,206,227)",
-            "rgb(31,120,180)",
-            "rgb(178,223,138)",
-            "rgb(51,160,44)",
-            "rgb(251,154,153)",
-            "rgb(227,26,28)",
-            "rgb(253,191,111)",
-            "rgb(255,127,0)",
-            "rgb(202,178,214)",
-            "rgb(106,61,154)",
-            "rgb(255,255,153)",
-            "rgb(177,89,40)",
-            "rgb(141,211,199)",
-            "rgb(255,255,179)",
-            "rgb(190,186,218)",
-            "rgb(251,128,114)",
-            "rgb(128,177,211)",
-            "rgb(253,180,98)",
-            "rgb(179,222,105)",
-            "rgb(252,205,229)",
-            "rgb(217,217,217)",
-            "rgb(188,128,189)",
-            "rgb(204,235,197)",
-            "rgb(255,237,111)",
+            "#A6CEE3",
+            "#1F78B4",
+            "#B2DF8A",
+            "#33A02C",
+            "#FB9A99",
+            "#E31A1C",
+            "#FDBF6F",
+            "#FF7F00",
+            "#CAB2D6",
+            "#6A3D9A",
+            "#FFFF99",
+            "#B15928",
+            "#8DD3C7",
+            "#FFFFB3",
+            "#BEBADA",
+            "#FB8072",
+            "#80B1D3",
+            "#FDB462",
+            "#B3DE69",
+            "#FCCDE5",
+            "#D9D9D9",
+            "#BC80BD",
+            "#CCEBC5",
+            "#FFED6F",
         ]
 
         idx = 0
